<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:cif="cif">
    <xsl:param name="xslShowHelp" select="cif:xslShowHelp"/>
    <xsl:param name="xslResourceDirectory" select="cif:xslResourceDirectory"/>
    <!-- Cant Application Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="cif:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslResourceDirectory}/engtheme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Cant Application Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Cant Application Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="cif:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="cif:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr />
                                <!-- Horizontal Alignment Data -->
                                <table cellpadding="1" width="100%">
                                    <xsl:for-each select="HorizontalAlignment[*/CantAlignment]">
                                        <tr>
                                            <th align="right" lang="en" width="20%"><br/>Horizontal Alignment:&#xa0; </th>
                                            <td align="left" valign="bottom" width="80%"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="white-space:nowrap;">Horizontal Description:&#xa0; </th>
                                            <td align="left"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Horizontal Style:&#xa0; </th>
                                            <td align="left"><xsl:value-of select="@style"/></td>
                                        </tr>
                                        <xsl:for-each select="Superelevation/CantAlignment">
                                            <tr>
                                                <th align="right" lang="en"><br/>Cant Name:&#xa0; </th>
                                                <td align="left" valign="bottom"><xsl:value-of select="@name"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" lang="en">Cant Description:&#xa0; </th>
                                                <td align="left"><xsl:value-of select="@description"/></td>
                                            </tr>
                                            <tr>
                                                <td colspan="12">
                                                    <table width="100%">
                                                        <xsl:if test="//@linearUnits = 'Imperial'">
                                                            <tr>
                                                                <th class="underline" lang="en" valign="bottom">Type</th>
                                                                <th class="underline" lang="en" valign="bottom">Station</th>
                                                                <th class="underline" lang="en" valign="bottom">Speed<br/>(mph)</th>
                                                                <th class="underline" lang="en" valign="bottom">Radius</th>
                                                                <th class="underline" lang="en" valign="bottom">Transition</th>
                                                                <th class="underline" lang="en" valign="bottom">Equilibrium<br/>Cant<br/>(in)</th>
                                                                <th class="underline" lang="en" valign="bottom">Applied<br/>Cant<br/>(in)</th>
                                                                <th class="underline" lang="en" valign="bottom">Deficiency<br/>Cant<br/>(in)</th>
                                                                <th class="underline" lang="en" valign="bottom">Non-Compensating<br/>Lateral<br/>Acceleration<br/>(ft/s*s)</th>
                                                                <th class="underline" lang="en" valign="bottom">Applied<br/>Rate of<br/>Change<br/>(in/s)</th>
                                                                <th class="underline" lang="en" valign="bottom">Deficiency<br/>Rate of<br/>Change<br/>(in/s)</th>
                                                                <th class="underline" lang="en" valign="bottom">Applied<br/>Gradient</th>
                                                            </tr>
                                                        </xsl:if>
                                                        <xsl:if test="//@linearUnits = 'Metric'">
                                                            <tr>
                                                                <th class="underline" lang="en" valign="bottom">Type</th>
                                                                <th class="underline" lang="en" valign="bottom">Station</th>
                                                                <th class="underline" lang="en" valign="bottom">Speed<br/>(kph)</th>
                                                                <th class="underline" lang="en" valign="bottom">Radius</th>
                                                                <th class="underline" lang="en" valign="bottom">Transition</th>
                                                                <th class="underline" lang="en" valign="bottom">Equilibrium<br/>Cant<br />(mm)</th>
                                                                <th class="underline" lang="en" valign="bottom">Applied<br/>Cant<br/>(mm)</th>
                                                                <th class="underline" lang="en" valign="bottom">Deficiency<br/>Cant<br/>(mm)</th>
                                                                <th class="underline" lang="en" valign="bottom">Non-Compensating<br/>Lateral<br/>Acceleration<br/>(m/s*s)</th>
                                                                <th class="underline" lang="en" valign="bottom">Applied<br/>Rate of<br/>Change<br/>(mm/s)</th>
                                                                <th class="underline" lang="en" valign="bottom">Deficiency<br/>Rate of<br/>Change<br/>(mm/s)</th>
                                                                <th class="underline" lang="en" valign="bottom">Applied<br/>Gradient</th>
                                                            </tr>
                                                        </xsl:if>
                                                        <!-- Cant Data -->
                                                        <xsl:for-each select="Cant">
                                                            <tr>
                                                                <td align="left"><xsl:value-of select="Start/@type"/></td>
                                                                <td align="right" style="white-space:nowrap;">
                                                                    <xsl:value-of select="cif:stationFormat(number(Start/station/@externalStation), string(Start/station/@externalStationName))"/>
                                                                </td>
                                                                <td align="right">
                                                                    <xsl:value-of select="cif:formatNumber(number(@designSpeed), 0)"/>
                                                                </td>
                                                                <td align="right">
                                                                    <xsl:value-of select="cif:distanceFormat(number(@radius))"/>
                                                                </td>
                                                                <td align="right"><xsl:value-of select="@transitionType"/></td>
                                                                <td align="right">
                                                                    <xsl:value-of select="cif:formatNumber(number(@equilibriumCant))"/>
                                                                </td>
                                                                <td align="right">
                                                                    <xsl:value-of select="cif:formatNumber(number(@appliedCant))"/>
                                                                </td>
                                                                <td align="right">
                                                                    <xsl:value-of select="cif:formatNumber(number(@cantDeficiency))"/>
                                                                </td>
                                                                <td align="right">
                                                                    <xsl:value-of select="cif:distanceFormat(number(@nonLateralAcceleration))"/>
                                                                </td>
                                                                <td align="right">
                                                                    <xsl:value-of select="cif:formatNumber(number(@appliedCantRateOfChange))"/>
                                                                </td>
                                                                <td align="right">
                                                                    <xsl:value-of select="cif:formatNumber(number(@cantDeficiencyRateOfChange))"/>
                                                                </td>
                                                                <td align="right">
                                                                    <xsl:value-of select="cif:formatNumber(number(@appliedGradient), 0)"/>
                                                                </td>
                                                            </tr>
                                                        </xsl:for-each>
                                                        <tr><td colspan="12">&#xa0;</td></tr>
                                                    </table>
                                                </td>
                                            </tr>
                                        </xsl:for-each>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <p class="normal1" lang="en">
            This report has no additional notes.
        </p>
    </xsl:template>
</xsl:stylesheet>
