<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:cif="cif">
  <xsl:param name="xslShowHelp" select="cif:xslShowHelp"/>
  <xsl:param name="xslResourceDirectory" select="cif:xslResourceDirectory"/>
  <xsl:param name="xslConvertToCY" select="cif:xslConvertToCY"/>
  <!-- Unique cross section surfaces -->
  <xsl:variable name="uniqueSurfaceName" select="//CrossSectionSurfaces/CrossSectionSurface[not (@name = preceding::CrossSectionSurface/@name)]/@name"/>
  <!-- Cross Section Gradebook with Northing/Easting Report -->
  <xsl:template match="/">
    <xsl:variable name="gridOut" select="cif:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
    <html>
      <head>
        <link rel="stylesheet" type="text/css" href="{$xslResourceDirectory}/engtheme.css"/>
        <!-- Title displayed in browser Title Bar -->
        <title lang="en">Cross Section Gradebook from Centerline</title>
      </head>
      <body>
        <xsl:choose>
          <xsl:when test="$xslShowHelp = 'true'">
            <xsl:call-template name="StyleSheetHelp"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:for-each select="InRoads">
              <center>
                <!-- Report Title -->
                <h2 lang="en">Cross Section Gradebook from Centerline</h2>
                <p lang="en">
                  Report Created:&#xa0; <xsl:value-of select="cif:date()"/><br />
                  Time:&#xa0; <xsl:value-of select="cif:time()"/>
                </p>
              </center>
              <!-- Cross Section Set Data -->
              <xsl:for-each select="CrossSectionSet">
                <table class="margin" cellpadding="2" width="90%">
                  <tbody>
                    <tr>
                      <th align="right" lang="en">Set Name:&#xa0; </th>
                      <td align="left" colspan="2">
                        <xsl:value-of select="@setName"/>
                      </td>
                    </tr>
                    <tr>
                      <th align="right" lang="en">Alignment Name:&#xa0; </th>
                      <td align="left" colspan="2">
                        <xsl:value-of select="@alignmentName"/>
                      </td>
                    </tr>
                    <tr>
                      <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                      <td align="left" style="font-size: 80%">
                        <xsl:value-of select="../@inputGridScaleFactor" />
                      </td>
                      <td align="right" lang="en" style="font-size: 80%">
                        <strong>Note:&#xa0; </strong>All units in this report are in
                        <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                        <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                        unless specified otherwise.
                      </td>
                    </tr>
                  </tbody>
                </table>
                <hr/>
                <!-- Cross Section Point Data -->
                <table class="margin" width="90%">
                  <xsl:for-each select="$uniqueSurfaceName">
                    <tr>
                      <th align="left" lang="en">Surface:&#xa0; </th>
                      <td align="left" colspan="3">
                        <xsl:value-of select="."/>
                      </td>
                    </tr>
                    <xsl:for-each select="//CrossSectionSurface[@name = current()]">
                      <xsl:for-each select="CrossSectionPoints">
                        <tr>
                          <th align="left" lang="en">Station:&#xa0; </th>
                          <td align="left" colspan="3" nowrap="nowrap">
                            <xsl:value-of select="cif:stationFormat(number(../../../Station/@externalStation), string(../../../Station/@externalStationName))"/>
                          </td>
                        </tr>
                        <tr>
                          <th align="left" lang="en">Feature</th>
                          <xsl:for-each select="CrossSectionPoint[@name] | CrossSectionPoint[not (@name) and @offset = 0.0]">
                            <td class="sidepad" align="right">
                              <xsl:value-of select="@name"/>
                            </td>
                          </xsl:for-each>
                        </tr>
                        <tr>
                          <th align="left" lang="en">Offset</th>
                          <xsl:for-each select="CrossSectionPoint[@name] | CrossSectionPoint[not (@name) and @offset = 0.0]">
                            <td align="right" style="padding-left:5px;padding-right:5px" nowrap="nowrap">
                              <xsl:value-of select="cif:distanceFormat(number(@offset))"/>
                            </td>
                          </xsl:for-each>
                        </tr>
                        <tr>
                          <th align="left" lang="en">Elevation</th>
                          <xsl:for-each select="CrossSectionPoint[@name] | CrossSectionPoint[not (@name) and @offset = 0.0]">
                            <td align="right" style="padding-left:5px;padding-right:5px" nowrap="nowrap">
                              <xsl:value-of select="cif:ordinateFormat(number(@elevation))"/>
                            </td>
                          </xsl:for-each>
                        </tr>
                        <tr>
                          <th align="left" lang="en">Slope</th>
                          <xsl:for-each select="CrossSectionPoint[@name] | CrossSectionPoint[not (@name) and @offset = 0.0]">
                            <xsl:choose>
                              <xsl:when test="round(@offset) &lt; 0">
                                <td align="right" style="padding-left:5px;padding-right:5px" nowrap="nowrap">
                                  <xsl:value-of select="cif:gradeFormat(number(@slope * -1))"/>
                                </td>
                              </xsl:when>
                              <xsl:when test="round(@offset) = 0">
                                <td align="right" style="padding-left:5px;padding-right:5px" nowrap="nowrap">
                                </td>
                              </xsl:when>
                              <xsl:when test="round(@offset) &gt; 0">
                                <td align="right" style="padding-left:5px;padding-right:5px" nowrap="nowrap">
                                  <xsl:value-of select="cif:ordinateFormat(number(preceding-sibling::CrossSectionPoint[1]/@slope))"/>
                                </td>
                              </xsl:when>
                            </xsl:choose>
                          </xsl:for-each>
                        </tr>
                        <tr>
                          <td>&#xa0;</td>
                        </tr>
                      </xsl:for-each>
                    </xsl:for-each>
                  </xsl:for-each>
                </table>
              </xsl:for-each>
            </xsl:for-each>
          </xsl:otherwise>
        </xsl:choose>
      </body>
    </html>
  </xsl:template>
  <xsl:template name="StyleSheetHelp">
    <p class="normal1" lang="en">
      This report has no additional notes.
    </p>
  </xsl:template>
</xsl:stylesheet>
