<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:cif="cif">
    <xsl:param name="xslShowHelp" select="cif:xslShowHelp"/>
    <xsl:strip-space elements="*"/>
    <xsl:param name="xslResourceDirectory" select="cif:xslResourceDirectory"/>
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="cif:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads">
                    <xsl:text/>
                    <xsl:text>* Profile Station Elevation Report (from Station Offset Points)&#xd;</xsl:text>
                    <xsl:text>* Report Created: </xsl:text><xsl:value-of select="cif:date()"/><xsl:text>&#xd;</xsl:text>

                    <xsl:for-each select="GeometryProject">
                        <xsl:text>* Project: </xsl:text><xsl:value-of select="@name"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* File Name: </xsl:text><xsl:value-of select="@file"/><xsl:text>&#xd;</xsl:text>

                        <xsl:for-each select="HorizontalAlignment[StationOffsetPoints]">
                            <xsl:text>*&#xd;</xsl:text>
                            <xsl:text>* Alignment Name: </xsl:text><xsl:value-of select="@name"/><xsl:text>&#xd;</xsl:text>
                            <xsl:text>*&#xd;</xsl:text>
                            <xsl:text>*      Station        Elevation&#xd;</xsl:text>
                            <xsl:text>*&#xd;</xsl:text>

                            <xsl:for-each select="StationOffsetPoints/StationOffsetPoint">
                                <xsl:variable name="fmtStation" select="cif:stationFormat(number(centerLinePoint/point/station/@externalStation), string(centerLinePoint/point/station/@externalStationName))"/>
                                <xsl:if test="not (@offsetAlignmentName = preceding-sibling::*/@offsetAlignmentName)">
                                    <xsl:text>* Offset (Specified) Alignment:  </xsl:text><xsl:value-of select="@offsetAlignmentName"/><xsl:text>&#xd;</xsl:text>
                                </xsl:if>
                                <xsl:value-of select="cif:columnFormat(string($fmtStation), 14)"/>
                                <xsl:value-of select="cif:columnDoubleFormat(number(centerLinePoint/point/@elevation), 17)"/>
                                <xsl:text>&#xd;</xsl:text>
                            </xsl:for-each>
                            <xsl:text>&#xd;</xsl:text>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template name="StyleSheetHelp">
        <xsl:text>    This report has no additional notes.</xsl:text>
    </xsl:template>
</xsl:stylesheet>
